﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using SampleData;
using System.IO;
using Infragistics.Documents.Excel;
using Infragistics.Controls.Grids;
using System.Collections.ObjectModel;
using System.Collections;

namespace ExcelDynamicColumns
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        private void btnLoadSampleData_Click(object sender, RoutedEventArgs e)
        {
            // Clear the grid
            ClearGrid();

            // Bind to a collection
            xamGrid1.ItemsSource = DataUtil.Products;
        }

        private void btnLoadFromXML_Click(object sender, RoutedEventArgs e)
        {
            // Clear the grid
            ClearGrid();

            OpenFileDialog openfileDialog = new OpenFileDialog();
            Workbook workbook1;

            if (openfileDialog.ShowDialog() == true)
            {
                // Load the excel file
                FileStream stream = openfileDialog.File.OpenRead();
                workbook1 = Workbook.Load(stream);
                stream.Close();

                Worksheet sheetOne = workbook1.Worksheets[0];

                // find the columns and get the column names
                List<string> columnNames = new List<string>();
                foreach (WorksheetCell cell in sheetOne.Rows[0].Cells)
                    columnNames.Add(cell.Value.ToString());

                // add them to the grid
                foreach (string columnName in columnNames)
                    xamGrid1.Columns.Add(new TextColumn { Key = columnName });

                // Create our collection
                ObservableCollection<IDictionary> data = new ObservableCollection<IDictionary>();
                foreach (WorksheetRow row in sheetOne.Rows)
                {
                    // Make sure to skip the first row since this is used for column names
                    if (row.Index != 0)
                    {
                        var dict = new Dictionary<string, object>();
                        var cells = row.Cells;
                        foreach (var cell in cells)
                        {
                            dict[columnNames[cell.ColumnIndex]] = cell.Value;
                        }
                        data.Add(dict);
                    }
                }
                // Call the extension method so the grid can interpret the data
                xamGrid1.ItemsSource = data.ToDataSource();
            }
        }

        private void btnSaveToXML_Click(object sender, RoutedEventArgs e)
        {
            Workbook workbook1 = new Workbook();

            Worksheet worksheet1 = workbook1.Worksheets.Add("Test Worksheet");

            WorksheetRow worksheetRow;
            Column gridCol;
            WorksheetCell worksheetCell;

            foreach (Row gridRow in this.xamGrid1.Rows)
            {
                worksheetRow = worksheet1.Rows[gridRow.Index + 1];

                for (int colIndex = 0; colIndex < this.xamGrid1.Columns.Count; colIndex++)
                {
                    worksheetRow.Cells[colIndex].Value = gridRow.Cells[colIndex].Value;

                    if (gridRow.Index == 0)
                    {
                        worksheetCell = worksheet1.Rows[0].Cells[colIndex];

                        gridCol = this.xamGrid1.Columns[colIndex] as Column;

                        worksheetCell.CellFormat.FillPatternForegroundColor = Colors.LightGray;
                        worksheetCell.CellFormat.LeftBorderColor = Color.FromArgb(0, 178, 178, 178);
                        worksheetCell.CellFormat.RightBorderColor = Color.FromArgb(0, 178, 178, 178);

                        worksheetCell.Value = gridCol.Key;
                    }
                }
            }

            SaveFileDialog saveFileDialog = new SaveFileDialog { Filter = "Excel files|*.xls", DefaultExt = "xls" };

            if (saveFileDialog.ShowDialog() == true)
            {
                Stream stream = saveFileDialog.OpenFile();
                workbook1.Save(stream);
                stream.Close();
            }
        }

        private void ClearGrid()
        {
            xamGrid1.ItemsSource = null;
            xamGrid1.Columns.Clear();
        }
    }
}
